<?php

function qooq_schema($url=null, $label, &$pos ){
	if( is_null($url) ){
		echo '<span>' . esc_html($label) . '</span> /';
	}else{
		echo '<span itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">' .
				'<a itemprop="item" href="' . esc_attr($url) . '">' .
					'<span itemprop="name">' . esc_html($label) . '</span></a>' .
				'<meta itemprop="position" content="' . $pos++ . '"></span> / ';
	}
}

function qooq_breadcrumb(){
	
	$pos = 1;
	$wp_obj = get_queried_object();
	
	echo '<div itemprop="Breadcrumb" itemscope itemtype="http://data-vocabulary.org/BreadcrumbList">';
	qooq_schema(home_url(), "ホーム", $pos);

	if( is_home() || is_front_page() ){
	}

	elseif( is_attachment() ){
	}

	elseif( is_single() ){
		$id    = $wp_obj->ID;
		$type  = $wp_obj->post_type;
		
		if( $type !== 'post' ){
			
			$tax = null;
			
			$taxonomies = get_object_taxonomies( $type, 'names');
			foreach($taxonomies as $tax_name){
				if( $tax_name !== 'post_format' ){
					$tax = $tax_name;
					break;
				}
			}
			
			$tax_url = get_post_type_archive_link($type);
			if( $tax_url !== false ){
				qooq_schema( $tax_url, get_post_type_object($type)->label, $pos );
			}
		}else{
			$tax = 'category';
		}
		
		if( !is_null($tax) ){
			$terms = get_the_terms( $id, $tax );
			
			if( $terms != false && !is_wp_error($terms) ){
				$term = $terms[0];
				
				if( $term->parent !== 0 ){
					$ancestors = array_reverse( get_ancestors( $term->term_id, $tax ) );
					
					foreach( $ancestors as $parent_id ){
						$parent_term = get_term( $parent_id, $tax );
						qooq_schema( get_term_link( $parent_id, $tax ), $parent_term->name, $pos );
					}
				}
				
				qooq_schema( get_term_link( $term->term_id, $tax ), $term->name, $pos );
			}
		}
	}

	elseif( is_page() ){
		$id     = $wp_obj->ID;
		$title  = $wp_obj->post_title;
		$parent = $wp_obj->post_parent;
		
		if( $parent !== 0 ){
			$ancestors = array_reverse( get_post_ancestors( $page_id ) );
			foreach( $ancestors as $parent_id ){
				qooq_schema( get_permalink( $parent_id ), get_the_title( $parent_id ), $pos );
			}
		}
		
		qooq_schema( get_permalink( $id ), $title, $pos );
	}

	elseif( is_post_type_archive() ){
		$title = $wp_obj->label;
		$type  = $wp_obj->name;
		
		qooq_schema( get_post_type_archive_link($type), $title, $pos );
	}

	elseif( is_date() ){
		$year  = get_query_var('year');
		$month = get_query_var('monthnum');
		$day   = get_query_var('day');
		
		if( $year !== 0 || $month !== 0 || $day !== 0 ){
			qooq_schema( get_year_link( $year ), $year . "年", $pos );
		}
		if( $month !== 0 || $day !== 0 ){
			qooq_schema( get_month_link( $year, $month ), $month . "月", $pos );
		}
		if( $day !== 0 ){
			qooq_schema( get_day_link( $year, $month, $day ), $day . "日", $pos );
		}
	}

	elseif( is_author() ){
		$title = $wp_obj->display_name . "の書いた記事";
		qooq_schema( null, $title, $pos );
	}

	elseif( is_archive() ){
		$id     = $wp_obj->term_id;
		$title  = $wp_obj->name;
		$parent = $wp_obj->parent;
		$tax    = $wp_obj->taxonoqooq_;
		
		if( is_tax() ){
			$type = get_post_type();
			if( $type ){
				qooq_schema( get_post_type_archive_link($type), get_post_type_object($type)->label, $pos );
			}
		}
		
		if( $parent !== 0 ){
			$ancestors = array_reverse( get_ancestors( $id, $tax ) );
			foreach( $ancestors as $parent_id ){
				$parent_term = get_term( $parent_id, $tax );
				qooq_schema( get_term_link( $parent_id, $tax ), $parent_term->name, $pos );
			}
		}
		
		qooq_schema( get_term_link( $id, $tax ), $title, $pos );
	}

	elseif( is_search() ){
		$title = "「" . get_search_query() . "」の検索結果";
		qooq_schema( null, $title, $pos );
	}

	elseif( is_404() ){
		$title = "該当の記事がありませんでした。";
		qooq_schema( null, $title, $pos );
	}

	else{
		qooq_schema( null, get_the_title(), $pos );
	}

	echo '</div>';
}
?>
